import 'dart:io';

import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/mixins.dart';

class SendVideoScreen extends StatefulWidget {
  @override
  _SendVideoScreenState createState() => _SendVideoScreenState();
}

class _SendVideoScreenState extends State<SendVideoScreen>
    with AccountTokenMixin {
  File _file;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('发送视频消息')),
      body: Center(
        child: DecoratedColumn(
          scrollable: true,
          padding: EdgeInsets.all(kSpaceBig),
          children: <Widget>[
            Text('发送方: $testAccount'),
            Text('单聊接收方: $peerAccount'),
            Text('聊天室id: $chatRoomId'),
            RaisedButton(
              onPressed: _handlePickFile,
              child: Text('选择视频'),
            ),
            if (_file != null) Text('视频路径: ${_file.path}'),
            RaisedButton(
              onPressed: _handleSendImage,
              child: Text('发送单聊信息'),
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                RaisedButton(
                  onPressed: handleEnterChatRoom,
                  child: Text('进入聊天室'),
                ),
                SPACE_NORMAL,
                RaisedButton(
                  onPressed: _handleSendChatRoomVideo,
                  child: Text('发送聊天室信息'),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }

  void _handleSendImage() async {
    if (_file != null) {
      Nim.instance
          .sendVideoMessage(
            sessionId: peerAccount,
            type: SessionType.p2p,
            videoFile: _file,
            duration: Duration(seconds: 50),
            width: 200,
            height: 200,
          )
          .loading(context)
          .then((value) => toast('发送成功'))
          .catchError(handle(context));
    } else {
      toast('发送内容不能为空');
    }
  }

  void _handleSendChatRoomVideo() async {
    if (_file != null) {
      Nim.instance
          .sendVideoMessage(
            sessionId: chatRoomId,
            type: SessionType.chatroom,
            videoFile: _file,
            duration: Duration(seconds: 50),
            width: 200,
            height: 200,
          )
          .loading(context)
          .then((value) => toast('发送成功'))
          .catchError(handle(context));
    } else {
      toast('发送内容不能为空');
    }
  }

  void _handlePickFile() async {
    File file = await FilePicker.getFile(type: FileType.video);
    setState(() {
      _file = file;
    });
  }
}
