import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:demo_widgets/demo_widgets.dart';
import 'package:flutter/material.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/login_logout/logout.screen.dart';
import 'package:nim_fluttify_example/src/message_send_recv/send_video.screen.dart';

import 'chatroom/enter_chatroom.screen.dart';
import 'chatroom/exit_chatroom.screen.dart';
import 'history/history.screen.dart';
import 'login_logout/login.screen.dart';
import 'message_send_recv/recv_message.screen.dart';
import 'message_send_recv/send_audio.screen.dart';
import 'message_send_recv/send_custom_message.screen.dart';
import 'message_send_recv/send_file.screen.dart';
import 'message_send_recv/send_image.screen.dart';
import 'message_send_recv/send_text.screen.dart';
import 'recent_session/fetch_recent_session.screen.dart';
import 'user_relationship/add_friend.screen.dart';
import 'user_relationship/add_to_black_list.screen.dart';
import 'user_relationship/black_list.screen.dart';
import 'user_relationship/remove_from_black_list.screen.dart';

class NimScreen extends StatefulWidget {
  @override
  _NimScreenState createState() => _NimScreenState();
}

class _NimScreenState extends State<NimScreen> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: StreamBuilder<StatusType>(
          initialData: StatusType.not_logged,
          stream: Nim.instance.onlineStatusStream,
          builder: (context, snapshot) {
            switch (snapshot.data) {
              case StatusType.connecting:
                return Text('网易云信(连接服务器中...)');
              case StatusType.logining:
                return Text('网易云信(登录中...)');
              case StatusType.logged:
                return Text('网易云信(已登录)');
              case StatusType.login_failed:
                return Text('网易云信(登录失败)');
              case StatusType.syncing:
                return Text('网易云信(数据同步中...)');
              case StatusType.net_broken:
                return Text('网易云信(连接断开...)');
              default:
                return Text('网易云信(未登录)');
            }
          },
        ),
      ),
      body: ListView(
        children: <Widget>[
          FunctionGroup(
            headLabel: '登录登出',
            opened: true,
            children: <Widget>[
              FunctionItem(
                label: '登录',
                sublabel: 'LoginScreen',
                target: LoginScreen(),
              ),
              FunctionItem(
                label: '登出',
                sublabel: 'LogoutScreen',
                target: LogoutScreen(),
              ),
            ],
          ),
          SPACE_BIG,
          FunctionGroup(
            headLabel: '消息收发',
            children: <Widget>[
              FunctionItem(
                label: '发送: 文本消息',
                sublabel: 'SendTextScreen',
                target: SendTextScreen(),
              ),
              FunctionItem(
                label: '发送: 图片消息',
                sublabel: 'SendImageScreen',
                target: SendImageScreen(),
              ),
              FunctionItem(
                label: '发送: 音频消息',
                sublabel: 'SendAudioScreen',
                target: SendAudioScreen(),
              ),
              FunctionItem(
                label: '发送: 视频消息',
                sublabel: 'SendVideoScreen',
                target: SendVideoScreen(),
              ),
              FunctionItem(
                label: '发送: 文件消息',
                sublabel: 'SendFileScreen',
                target: SendFileScreen(),
              ),
//              FunctionItem(
//                label: '发送: 地理位置消息',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
//              FunctionItem(
//                label: '发送: 机器人提问消息',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
//              FunctionItem(
//                label: '发送: 机器人跳转消息',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
//              FunctionItem(
//                label: '发送: 通知消息',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
//              FunctionItem(
//                label: '发送: 提示消息',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
//              FunctionItem(
//                label: '发送: 可自定义发送方的本地消息',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
              FunctionItem(
                label: '发送: 自定义消息',
                sublabel: 'SendCustomMessageScreen',
                target: SendCustomMessageScreen(),
              ),
              FunctionItem(
                label: '消息接收: 消息接收',
                sublabel: 'RecvMessageScreen',
                target: RecvMessageScreen(),
              ),
            ],
          ),
          SPACE_BIG,
          FunctionGroup(
            headLabel: '用户关系托管',
            children: <Widget>[
              FunctionItem(
                label: '好友关系: 添加好友',
                sublabel: 'AddFriendScreen',
                target: AddFriendScreen(),
              ),
//              FunctionItem(
//                label: '好友关系: 通过/拒绝对方好友请求',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
//              FunctionItem(
//                label: '好友关系: 删除好友',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
//              FunctionItem(
//                label: '好友关系: 监听好友关系变化',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
//              FunctionItem(
//                label: '好友关系: 获取好友列表',
//                sublabel: 'FriendListScreen',
//                target: FriendListScreen(),
//              ),
//              FunctionItem(
//                label: '好友关系: 根据好友备注名获取好友账号',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
//              FunctionItem(
//                label: '好友关系: 判断用户身份为我的好友',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
//              FunctionItem(
//                label: '好友关系: 更新好友关系',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
              FunctionItem(
                label: '黑名单: 加入黑名单',
                sublabel: 'AddToBlackListScreen',
                target: AddToBlackListScreen(),
              ),
              FunctionItem(
                label: '黑名单: 移出黑名单',
                sublabel: 'RemoveFromBlackListScreen',
                target: RemoveFromBlackListScreen(),
              ),
//              FunctionItem(
//                label: '黑名单: 监听黑名单变化',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
              FunctionItem(
                label: '黑名单: 获取黑名单列表',
                sublabel: 'BlackListScreen',
                target: BlackListScreen(),
              ),
//              FunctionItem(
//                label: '黑名单: 判断用户是否被拉进黑名单',
//                sublabel: 'TODOScreen',
//                target: TODOScreen(),
//              ),
            ],
          ),
          SPACE_BIG,
          FunctionGroup(
            headLabel: '聊天室',
            children: <Widget>[
              FunctionItem(
                label: '进入聊天室',
                sublabel: 'EnterChatroomScreen',
                target: EnterChatroomScreen(),
              ),
              FunctionItem(
                label: '离开聊天室',
                sublabel: 'ExitChatroomScreen',
                target: ExitChatroomScreen(),
              ),
            ],
          ),
          SPACE_BIG,
          FunctionGroup(
            headLabel: '历史记录',
            children: <Widget>[
              FunctionItem(
                label: '历史记录',
                sublabel: 'HistoryScreen',
                target: HistoryScreen(),
              ),
            ],
          ),
          SPACE_BIG,
          FunctionGroup(
            headLabel: '最近会话',
            children: <Widget>[
              FunctionItem(
                label: '获取最近会话列表',
                sublabel: 'RecentSessionScreen',
                target: RecentSessionScreen(),
              ),
            ],
          ),
        ],
      ),
    );
  }
}
